@@ -7,13 +7,13 @@ use Git::Lint::Config;
 use Try::Tiny;
 use Module::Loader;
 
-our $VERSION = '0.008';
+our $VERSION = '0.009';
 
 sub new {
     my $class = shift;
     my $self  = {
         issues    => undef,
-        '_config' => Git::Lint::Config->new(),
+        '_config' => Git::Lint::Config->load(),
     };
 
     bless $self, $class;
@@ -150,6 +150,10 @@ Then build, test, and install.
  make
  make test && make install
 
+C<Git::Lint> can also be installed using L<cpanm>.
+
+ cpanm Git::Lint
+
 =head1 CONFIGURATION
 
 Configuration is done through C<git config> files (F<~/.gitconfig> or F</repo/.git/config>).
@@ -184,7 +188,7 @@ Message check profiles can also be defined.
 
 An example configuration is provided in the C<examples> directory of this project.
 
-=head1 INSTALLATION
+=head1 ENABLING CHECKS FOR REPOS
 
 To enable as a C<pre-commit> hook, copy the C<pre-commit> script from the C<example/hooks> directory into the C<.git/hooks> directory of the repo you want to check.
 
