@@ -5,7 +5,7 @@ use warnings;
 
 use parent 'Git::Lint::Check::Message';
 
-our $VERSION = '0.008';
+our $VERSION = '0.009';
 
 my $check_name        = 'blank line after summary';
 my $check_description = 'first line must be followed by a blank line';
@@ -48,7 +48,7 @@ Git::Lint::Check::Message::BlankLineAfterSummary - check for blank line after su
 
  my $plugin = Git::Lint::Check::Message::BlankLineAfterSummary->new();
 
- my $input = $plugin->message();
+ my $input = $plugin->message( file => $filepath );
  my @lines = @{$input};
  my @issues = $plugin->check( \@lines );
 
