@@ -5,7 +5,7 @@ use warnings;
 
 use parent 'Git::Lint::Check::Message';
 
-our $VERSION = '0.008';
+our $VERSION = '0.009';
 
 my $check_name        = 'summary ending period';
 my $check_description = 'summary must not end with a period';
@@ -42,7 +42,7 @@ Git::Lint::Check::Message::SummaryEndingPeriod - check for no summary ending per
 
  my $plugin = Git::Lint::Check::Message::SummaryEndingPeriod->new();
 
- my $input = $plugin->message();
+ my $input = $plugin->message( file => $filepath );
  my @lines = @{$input};
  my @issues = $plugin->check( \@lines );
 
